package service

import (
	"github.com/pkg/errors"
	"gorm.io/gorm"
	req "sghgogs.com/micro/shopping-service-service/domain/model/request"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"sghgogs.com/micro/shopping-service-service/utils"
	"time"
)

func (svc *Service) GetRefundRequestList(query *pb.GetRefundRequestListRequest) ([]*pb.RefundRequest, int64, error) {
	list, i, err := svc.Repository.GetRefundRequestList(query)
	refundRequests := make([]*pb.RefundRequest, 0)
	if err != nil {
		if errors.Is(err, gorm.ErrRecordNotFound) {
			return refundRequests, 0, nil // 记录不存在
		} else {
			return refundRequests, 0, err
		}
	}
	return svc.getRefundRequestResItems(list), i, nil
}

func (svc *Service) getRefundRequestResItems(items []req.RefundRequest) []*pb.RefundRequest {
	requests := make([]*pb.RefundRequest, 0)
	for _, item := range items {
		requests = append(requests, svc.getRefundRequestResItem(item))
	}
	return requests
}
func (svc *Service) getRefundRequestResItem(request req.RefundRequest) *pb.RefundRequest {
	var updatedAt int64
	if request.UpdatedAt != nil {
		if request.CreatedAt.Truncate(time.Second) == request.UpdatedAt.Truncate(time.Second) {
			request.UpdatedAt = nil
		} else {
			updatedAt = utils.ConvertTimeToInt64(*request.UpdatedAt)
		}
	}
	refundRequest := pb.RefundRequest{
		Id:       request.ID,
		UserId:   request.UserID,
		OrderId:  request.OrderID,
		Reason:   request.Reason,
		Status:   request.Status,
		CreateAt: utils.ConvertTimeToInt64(request.CreatedAt),
		UpdateAt: updatedAt,
	}
	return &refundRequest
}
