package order

import (
	"context"
	"sghgogs.com/micro/shopping-service-service/domain/service"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"sghgogs.com/micro/shopping-service-service/utils"
	"strconv"
)

type Order struct {
	Service   service.IService
	Namespace string
}

func (svc *Order) CompleteDelivery(ctx context.Context, data *pb.CompleteDeliveryRequest, rsp *pb.CompleteDeliveryResponse) error {
	loadMetadata, err := utils.LoadMetadata(ctx, svc.Namespace)
	if err != nil {
		return err
	}
	if value, isOk := loadMetadata["user_id"]; isOk {
		userID, _ := strconv.ParseInt(value, 10, 64)
		data.ApproverId = userID
		if err = svc.Service.CompleteDelivery(data); err != nil {
			return err
		}
	}
	return nil
}

func (svc *Order) GetOrder(ctx context.Context, query *pb.GetOrderRequest, rsp *pb.GetOrderResponse) error {
	order, err := svc.Service.GetOrder(query)
	if err != nil {
		return err
	}
	rsp.Data = order
	return nil
}

func (svc *Order) ConfirmOrderProcessing(ctx context.Context, data *pb.ConfirmOrderProcessingRequest, response *pb.ConfirmOrderProcessingResponse) error {
	loadMetadata, err := utils.LoadMetadata(ctx, svc.Namespace)
	if err != nil {
		return err
	}
	if value, isOk := loadMetadata["user_id"]; isOk {
		userID, _ := strconv.ParseInt(value, 10, 64)
		data.ApproverId = userID
		if err = svc.Service.ConfirmOrderProcessing(data); err != nil {
			return err
		}
	}
	return nil
}

func (svc *Order) InitiateShipping(ctx context.Context, data *pb.InitiateShippingRequest, response *pb.InitiateShippingResponse) error {
	loadMetadata, err := utils.LoadMetadata(ctx, svc.Namespace)
	if err != nil {
		return err
	}
	if value, isOk := loadMetadata["user_id"]; isOk {
		userID, _ := strconv.ParseInt(value, 10, 64)
		data.ApproverId = userID
		if err = svc.Service.InitiateShipping(data); err != nil {
			return err
		}
	}
	return nil
}

func (svc *Order) GetOrderList(ctx context.Context, query *pb.GetOrderListRequest, rsp *pb.GetOrderListResponse) error {
	list, i, err := svc.Service.GetOrderList(query)
	if err != nil {
		return err
	}
	rsp.Items = list
	rsp.TotalCount = i
	return nil
}

func (svc *Order) CreateOrderByUserID(ctx context.Context, request *pb.CreateOrderByUserIDRequest, response *pb.CreateOrderByUserIDResponse) error {
	// TODO implement me
	panic("implement me")
}

func (svc *Order) GetOrderListByUserID(ctx context.Context, request *pb.GetOrderListByUserIDRequest, response *pb.GetOrderListByUserIDResponse) error {
	// TODO implement me
	panic("implement me")
}

func (svc *Order) ApplyRefund(ctx context.Context, request *pb.ApplyRefundRequest, response *pb.ApplyRefundResponse) error {
	// TODO implement me
	panic("implement me")
}

func (svc *Order) CancelOrderByUserIDAndOrderID(ctx context.Context, request *pb.CancelOrderByUserIDAndOrderIDRequest, response *pb.CancelOrderByUserIDAndOrderIDResponse) error {
	// TODO implement me
	panic("implement me")
}

func (svc *Order) GetOrderItemsByUserIDAndOrderID(ctx context.Context, request *pb.GetOrderItemsByUserIDAndOrderIDRequest, response *pb.GetOrderItemsByUserIDAndOrderIDResponse) error {
	// TODO implement me
	panic("implement me")
}

func (svc *Order) UpdateOrderAddressByUserIDAndOrderID(ctx context.Context, request *pb.UpdateOrderAddressByUserIDAndOrderIDRequest, response *pb.UpdateOrderAddressByUserIDAndOrderIDResponse) error {
	// TODO implement me
	panic("implement me")
}
