package account

import (
	"fmt"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"gorm.io/gorm/schema"
	req "sghgogs.com/micro/shopping-service-service/domain/model/request"
	"sghgogs.com/micro/shopping-service-service/domain/repository"
	"sghgogs.com/micro/shopping-service-service/domain/service"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"testing"
	"time"
)

func TestAccount(t *testing.T) {
	address := fmt.Sprintf("%v:%v@(%v:%v)/%v?charset=utf8mb4,utf8&parseTime=True&loc=Local", "root", "xugang131500", "47.56.16.206", 3306, "shopping_wenke")
	db, err := gorm.Open(mysql.Open(address), &gorm.Config{
		Logger: logger.Default.LogMode(logger.Info),
		NamingStrategy: schema.NamingStrategy{
			SingularTable: true,
		}})
	if err != nil {
		t.Fatal(err)
	}
	repo := repository.NewRepository(db)
	t.Run("初始化表", func(t *testing.T) {
		err = repo.InitTable()
		fmt.Println(err)
		// db.Migrator().DropIndex(req.Region{}, "idx_region_parent_id_country_code")
	})
	_ = service.NewService(repo, "shopping_wenke")
	t.Run("充值", func(t *testing.T) {
		account := req.UserAccount{
			UserID:       1,
			Balance:      10000000000,
			IsActive:     true,
			OpenDate:     time.Now(),
			LastActivity: time.Now(),
			CreatedAt:    time.Now(),
		}
		db.Model(&req.UserAccount{}).Create(&account)
		bill := req.Bill{
			AccountID:   account.ID,
			Amount:      account.Balance,
			Type:        pb.BillTypeEnum_BILL_INCOME,
			Description: "系统充值",
			CreatedAt:   time.Now(),
		}
		db.Model(&req.Bill{}).Create(&bill)
	})
}
