package address

import (
	"fmt"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"gorm.io/gorm/schema"
	"sghgogs.com/micro/shopping-service-service/domain/repository"
	"sghgogs.com/micro/shopping-service-service/domain/service"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"testing"
)

func TestAddress(t *testing.T) {
	address := fmt.Sprintf("%v:%v@(%v:%v)/%v?charset=utf8mb4,utf8&parseTime=True&loc=Local", "root", "xugang131500", "47.56.16.206", 3306, "shopping_wenke")
	db, err := gorm.Open(mysql.Open(address), &gorm.Config{
		Logger: logger.Default.LogMode(logger.Info),
		NamingStrategy: schema.NamingStrategy{
			SingularTable: true,
		}})
	if err != nil {
		t.Fatal(err)
	}
	repo := repository.NewRepository(db)
	newService := service.NewService(repo, "shoppingservice")
	// 114.02,32.81
	t.Run("创建", func(t *testing.T) {
		// err2 := newService.CreateAddress(&pb.CreateAddressRequest{
		// 	UserId:    1,
		// 	Country:   "CN",
		// 	Province:  "河南省",
		// 	City:      "驻马店市",
		// 	District:  "确山县",
		// 	Street:    "铁北路",
		// 	Remark:    "",
		// 	IsDefault: 0,
		// 	Location: &pb.Location{
		// 		Lon: 114.02,
		// 		Lat: 32.81,
		// 	},
		// })
		// fmt.Println(err2)
		err2 := newService.CreateAddress(&pb.CreateAddressRequest{
			UserId:    2,
			Country:   "CN",
			Province:  "广东省",
			City:      "惠州市",
			District:  "大亚湾区澳头镇",
			Street:    "安惠大道",
			Remark:    "11号楼当代MOMA商品湾",
			IsDefault: 1,
			Location: &pb.Location{
				Lon: 116.44,
				Lat: 39.95,
			},
		})
		fmt.Println(err2)
	})
	t.Run("查询列表", func(t *testing.T) {
		list, i, err2 := newService.GetAddressList(&pb.GetAddressListRequest{
			Page:     1,
			PageSize: 10,
		})
		fmt.Println(list)
		fmt.Println(i)
		fmt.Println(err2)
	})
	t.Run("获取详情", func(t *testing.T) {
		getAddress, err2 := newService.GetAddress(&pb.GetAddressRequest{
			AddressId: 1,
		})
		fmt.Println(getAddress)
		fmt.Println(err2)
	})
	t.Run("更新", func(t *testing.T) {
		getAddress, err2 := newService.GetAddress(&pb.GetAddressRequest{
			AddressId: 1,
		})
		fmt.Println(err2)
		err2 = newService.UpdateAddress(&pb.UpdateAddressRequest{
			AddressId: getAddress.Id,
			Country:   getAddress.Country,
			Province:  getAddress.Province,
			City:      getAddress.City,
			District:  getAddress.District,
			Street:    "铁北路和平街交叉口",
			Remark:    getAddress.Remark,
			IsDefault: getAddress.IsDefault,
			Location: &pb.Location{
				Lon: getAddress.Location.Lon,
				Lat: getAddress.Location.Lat,
			},
		})
		fmt.Println("err2", err2)
	})

	t.Run("删除", func(t *testing.T) {
		err2 := newService.DeleteAddress(&pb.DeleteAddressRequest{AddressId: 9})
		fmt.Println(err2)
	})
}
