package permission

import (
	"context"
	"fmt"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"gorm.io/gorm/schema"
	"sghgogs.com/micro/shopping-service-service/domain/repository"
	"sghgogs.com/micro/shopping-service-service/domain/service"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"testing"
	"time"
)

func TestRole(t *testing.T) {
	address := fmt.Sprintf("%v:%v@(%v:%v)/%v?charset=utf8mb4,utf8&parseTime=True&loc=Local", "root", "xugang131500", "47.56.16.206", 3306, "shopping_wenke")
	db, err := gorm.Open(mysql.Open(address), &gorm.Config{
		Logger: logger.Default.LogMode(logger.Info),
		NamingStrategy: schema.NamingStrategy{
			SingularTable: true,
		}})
	if err != nil {
		t.Fatal(err)
	}
	repo := repository.NewRepository(db)
	newService := service.NewService(repo, "shoppingservice_wanke")
	t.Run("创建", func(t *testing.T) {
		err2 := newService.CreatePermission(context.Background(), &pb.CreatePermissionRequest{
			Name:        "shoppingservice_wanke",
			Description: "超级管理员",
			Endpoint:    "UserShoppingService.CreateUser",
			Status:      pb.StatusEnum_ENABLED,
		})
		fmt.Println(err2)
	})
	t.Run("更新", func(t *testing.T) {
		roles := []int64{1, 2}
		err2 := newService.UpdatePermission(context.Background(), &pb.UpdatePermissionRequest{
			PermissionId: 1,
			Description:  "创建",
			Roles:        roles,
			Endpoint:     "UserShoppingService.CreateUser",
		})
		fmt.Println(err2)
	})
	t.Run("删除", func(t *testing.T) {
		newService.DeletePermission(&pb.DeletePermissionRequest{PermissionId: 1})
	})
	t.Run("批量创建", func(t *testing.T) {
		items := []*pb.Permission{
			{
				Name:        "shopping_client_service_wanke",
				Description: "客户端 查询地址管理列表",
				Endpoint:    "ShoppingAddressClient.GetClientAddress",
				Status:      pb.StatusEnum_ENABLED,
			},
		}
		newService.CreateMultiplePermissions(context.Background(), &pb.CreateMultiplePermissionsRequest{
			Roles: []int64{3},
			Items: items,
		})
	})
	t.Run("比较", func(t *testing.T) {
		fmt.Println(time.Now().Local() == time.Now().Local())
	})
	t.Run("列表", func(t *testing.T) {
		list, i, err2 := newService.GetPermissionList(&pb.GetPermissionListRequest{
			Page:     1,
			PageSize: 10,
		})
		fmt.Println(list)
		fmt.Println(i)
		fmt.Println(err2)
	})
	t.Run("详情", func(t *testing.T) {
		permission, err2 := newService.GetPermission(&pb.GetPermissionRequest{PermissionId: 1})
		fmt.Println(permission)
		fmt.Println(err2)
	})

}
