package region

import (
	"encoding/json"
	"fmt"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"gorm.io/gorm/schema"
	"io/ioutil"
	req "sghgogs.com/micro/shopping-service-service/domain/model/request"
	"sghgogs.com/micro/shopping-service-service/domain/repository"
	"sghgogs.com/micro/shopping-service-service/domain/service"
	"testing"
)

type RegionItem struct {
	RegionID        string `json:"region_id"`
	RegionName      string `json:"region_name"`
	RegionShortName string `json:"region_short_name"`
	RegionCode      string `json:"region_code"`
	RegionParentID  string `json:"region_parent_id"`
	RegionLevel     int    `json:"region_level"`
}

type T2 struct {
	Code         string `json:"code"`
	Name         string `json:"name"`
	StreetCode   string `json:"streetCode"`
	AreaCode     string `json:"areaCode"`
	CityCode     string `json:"cityCode"`
	ProvinceCode string `json:"provinceCode"`
}

func TestRegion(t *testing.T) {
	address := fmt.Sprintf("%v:%v@(%v:%v)/%v?charset=utf8mb4,utf8&parseTime=True&loc=Local", "root", "xugang131500", "47.56.16.206", 3306, "shopping_wenke")
	db, err := gorm.Open(mysql.Open(address), &gorm.Config{
		Logger: logger.Default.LogMode(logger.Info),
		NamingStrategy: schema.NamingStrategy{
			SingularTable: true,
		}})
	if err != nil {
		t.Fatal(err)
	}
	repo := repository.NewRepository(db)
	_ = service.NewService(repo, "shoppingservice_wanke")
	// service.NewService(repo, "shoppingservice_wanke")
	t.Run("初始化表", func(t *testing.T) {
		err = repo.InitTable()
		fmt.Println(err)
	})
	t.Run("新增表", func(t *testing.T) {
		data, err := ioutil.ReadFile("villages.json")
		if err != nil {
			fmt.Println("Error reading file:", err)
			return
		}
		// 解析 JSON 数据
		var regions []T2
		if err := json.Unmarshal(data, &regions); err != nil {
			fmt.Println("Error parsing JSON:", err)
			return
		}
		items := make([]req.Region, 0)
		for _, item := range regions {
			region := req.Region{
				CountryCode:    "CN",
				RegionID:       item.Code,
				RegionName:     item.Name,
				RegionParentID: item.StreetCode,
				RegionLevel:    5,
			}
			items = append(items, region)
		}
		for i := 0; i < len(items); i += 1000 {
			end := i + 1000
			if end > len(items) {
				end = len(items)
			}
			err := db.Model(&req.Region{}).CreateInBatches(items[i:end], len(items[i:end])).Error
			if err != nil {
				fmt.Println("失败:", err)
			}
		}
		// err = db.Model(&req.Region{}).Create(&regions).Error
	})
}
