package role

import (
	"context"
	"fmt"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"gorm.io/gorm/schema"
	"sghgogs.com/micro/shopping-service-service/domain/repository"
	"sghgogs.com/micro/shopping-service-service/domain/service"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"testing"
)

func TestRole(t *testing.T) {
	address := fmt.Sprintf("%v:%v@(%v:%v)/%v?charset=utf8mb4,utf8&parseTime=True&loc=Local", "root", "xugang131500", "47.56.16.206", 3306, "shopping_wenke")
	db, err := gorm.Open(mysql.Open(address), &gorm.Config{
		Logger: logger.Default.LogMode(logger.Info),
		NamingStrategy: schema.NamingStrategy{
			SingularTable: true,
		}})
	if err != nil {
		t.Fatal(err)
	}
	repo := repository.NewRepository(db)
	newService := service.NewService(repo, "shoppingservice_wanke")
	t.Run("创建", func(t *testing.T) {
		err2 := newService.CreateRole(context.Background(), &pb.CreateRoleRequest{
			Name:        "user",
			Description: "普通用户",
		})
		fmt.Println(err2)
	})
	t.Run("列表", func(t *testing.T) {
		list, i, err2 := newService.GetRoleList(&pb.GetRoleListRequest{
			Page:     1,
			PageSize: 10,
		})
		fmt.Println(list)
		fmt.Println(i)
		fmt.Println(err2)
	})
	t.Run("关联", func(t *testing.T) {
		newService.UpdateUserRoles(&pb.UpdateUserRolesRequest{UserId: 4, Roles: []int64{3}})
	})
	t.Run("查询所有", func(t *testing.T) {
		roles, err2 := newService.GetAllRoles()
		fmt.Println(roles, err2)
		// newService.UpdateUserRoles(&pb.UpdateUserRolesRequest{UserId: 4, Roles: []int64{3}})
	})
	t.Run("详情", func(t *testing.T) {
		role, err2 := newService.GetRole(&pb.GetRoleRequest{RoleId: 1})
		fmt.Println(role)
		fmt.Println(err2)
	})

}
