package user

import (
	"fmt"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"gorm.io/gorm/schema"
	req "sghgogs.com/micro/shopping-service-service/domain/model/request"
	"sghgogs.com/micro/shopping-service-service/domain/repository"
	"sghgogs.com/micro/shopping-service-service/domain/service"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"testing"
	"time"
)

func TestUser(t *testing.T) {
	address := fmt.Sprintf("%v:%v@(%v:%v)/%v?charset=utf8mb4,utf8&parseTime=True&loc=Local", "root", "xugang131500", "47.56.16.206", 3306, "shopping_wenke")
	db, err := gorm.Open(mysql.Open(address), &gorm.Config{
		Logger: logger.Default.LogMode(logger.Info),
		NamingStrategy: schema.NamingStrategy{
			SingularTable: true,
		}})
	if err != nil {
		t.Fatal(err)
	}
	repo := repository.NewRepository(db)
	t.Run("初始化表", func(t *testing.T) {
		err = repo.InitTable()
		fmt.Println(err)
		// db.Migrator().DropIndex(req.Region{}, "idx_region_parent_id_country_code")
	})
	service := service.NewService(repo, "shopping_wenke")

	t.Run("登录", func(t *testing.T) {
		login, i, err2 := service.Login(&pb.LoginRequest{
			Username: "john_doe",
			Password: "123456",
			Code:     "26825aad-f6af-4d7c-a576-b40a75280e5b",
		})
		fmt.Println(login)
		fmt.Println(i)
		fmt.Println(err2)
	})
	t.Run("创建账号", func(t *testing.T) {
		// user := &pb.CreateUserRequest{
		// 	Username:    "admin",
		// 	Password:    "123456",
		// 	PhoneNumber: "13900000000",
		// 	Email:       "john@example.com",
		// 	Avatar:      "https://wpimg.wallstcn.com/f778738c-e4f8-4870-b634-56703b4acafe.gif",
		// }
		// err = service.CreateUser(user)
		// fmt.Println("err", err)
	})
	t.Run("删除", func(t *testing.T) {
		// service.DeleteUser(&pb.DeleteUserRequest{UserId: 7})
	})
	t.Run("更新", func(t *testing.T) {
	})
	t.Run("查询User数据", func(t *testing.T) {
		// group, err2 := service.GetUserGroup(&pb.GetUserGroupRequest{GroupId: 2})
		// fmt.Println(group)
		// fmt.Println(err2)
		var user []req.User
		db.Model(&req.User{}).
			Where("group_id = ?", 2).
			Order("id desc").Find(&user)
		fmt.Println(user)
	})
	t.Run("删除", func(t *testing.T) {
	})
	t.Run("查询详情", func(t *testing.T) {
		user, err2 := service.GetUser(&pb.GetUserRequest{UserId: 1})
		fmt.Println(user)
		// // db.Preload("ShoppingCart").Where("id = ? AND status = ?", 1, pb.StatusEnum_ENABLED).First(&user)
		// // fmt.Println("user", user.ShoppingCart)
		fmt.Println(err2)
	})
	t.Run("修改手机号", func(t *testing.T) {
		// err2 := service.UpdateUserPhoneNumber(&pb.UpdateUserPhoneNumberRequest{
		// 	UserId:         4,
		// 	NewPhoneNumber: "13888888888",
		// })
		// fmt.Println(err2)
	})
	t.Run("设置状态", func(t *testing.T) {
		// service.ToggleUser(&pb.ToggleUserRequest{
		// 	UserId: 1,
		// 	Status: pb.StatusEnum_ENABLED,
		// })
	})
	t.Run("测试时间", func(t *testing.T) {
		date := time.Now().AddDate(0, 0, 1)
		fmt.Println(date)
		fmt.Println(time.Now().Before(date))
	})
	t.Run("查询", func(t *testing.T) {
		list, i, err2 := service.GetUserList(&pb.GetUserListRequest{
			Page:     1,
			PageSize: 10,
		})
		fmt.Println(list)
		fmt.Println(i)
		fmt.Println(err2)
	})
	t.Run("创建分组", func(t *testing.T) {
		err2 := service.CreateUserGroup(&pb.CreateUserGroupRequest{
			Name:        "前端用户-A组",
			Description: "默认进入注册A组",
			CreatedBy:   "system",
		})
		fmt.Println(err2)
	})
	t.Run("测试", func(t *testing.T) {
		// group, err2 := service.GetUserGroup(&pb.GetUserGroupRequest{Code: "17a78673-9762-4e9e-8f87-595a049f75bf"})
		// fmt.Println(group.Id)
		// fmt.Println(err2)
		login, i, err2 := service.Login(&pb.LoginRequest{
			Username: "admin",
			Password: "123456",
			Code:     "17a78673-9762-4e9e-8f87-595a049f75bf",
		})
		fmt.Println(login)
		fmt.Println(i)
		fmt.Println(err2)
	})
	// service.NewService(repo)
}
